@@ -1,14 +1,11 @@
 from os import path
-from json import load
 from pkgutil import walk_packages
-from appsync_router import Router
+from appsync_router import Router, logger
 
+logger.setLevel("DEBUG")
 
 module_dir = path.dirname(__file__)
-with open(f"{module_dir}/config.json", "r") as f:
-    config = load(f)
-
-routes = Router(**config)
+routes = Router()
 
 resolvers = [x.name for x in walk_packages(path=["resolvers"])]
 
